#   DrCr: Web-based double-entry bookkeeping framework
#   Copyright (C) 2022  Lee Yingtong Li (RunasSudo)
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.

from sqlalchemy import Column, DateTime, ForeignKey, Integer, String
from sqlalchemy.orm import relationship

from ..database import Base
from ..models import Amount, Posting, Transaction

class GeneralJournalTransaction(Base, Transaction):
	__tablename__ = 'general_journal_transactions'
	
	id = Column(Integer, primary_key=True)
	
	dt = Column(DateTime)
	description = Column(String)
	
	postings = relationship('GeneralJournalPosting', back_populates='transaction', cascade='all, delete')

class GeneralJournalPosting(Base, Posting):
	__tablename__ = 'general_journal_postings'
	
	id = Column(Integer, primary_key=True)
	transaction_id = Column(Integer, ForeignKey('general_journal_transactions.id'))
	
	description = Column(String)
	account = Column(String)
	quantity = Column(Integer)
	commodity = Column(String)
	
	transaction = relationship('GeneralJournalTransaction', back_populates='postings')
	
	def amount(self):
		return Amount(self.quantity, self.commodity)
