#   DrCr: Web-based double-entry bookkeeping framework
#   Copyright (C) 2022  Lee Yingtong Li (RunasSudo)
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.

from flask import Flask

from .database import db_session, init_db
from .general_journal.models import GeneralJournalTransaction
from .statements.models import StatementLine, StatementLineTransaction

app = Flask(__name__)

def all_transactions():
	return (
		GeneralJournalTransaction.query.all() +
		StatementLineTransaction.query.all() +
		[line.into_transaction() for line in StatementLine.query.all() if len(line.postings) == 0]  # TODO: Filter in SQL
	)

from . import views
from .general_journal import views
from .reports import views
from .statements import views

@app.cli.command('initdb')
def initdb():
	init_db()

@app.teardown_appcontext
def shutdown_session(exception=None):
	db_session.remove()
